summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoParagCounter.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kotext/KoParagCounter.h')
-rw-r--r--lib/kotext/KoParagCounter.h82
1 files changed, 41 insertions, 41 deletions
diff --git a/lib/kotext/KoParagCounter.h b/lib/kotext/KoParagCounter.h
index f58a1b93..4f32df58 100644
--- a/lib/kotext/KoParagCounter.h
+++ b/lib/kotext/KoParagCounter.h
@@ -17,9 +17,9 @@
* Boston, MA 02110-1301, USA.
*/
-#include <qstring.h>
+#include <tqstring.h>
#include <koffice_export.h>
-class QDomElement;
+class TQDomElement;
class KoXmlWriter;
class KoGenStyle;
class KoTextParag;
@@ -40,7 +40,7 @@ public:
/** Invalidate the internal cache. Use it whenever the number associated with this
* counter may have changed. */
- void invalidate();
+ void tqinvalidate();
/** Return the current value of the counter as a number.
*/
@@ -48,12 +48,12 @@ public:
/** Return the current value of the counter as a text.
* This returns only the current level, e.g. "1."
*/
- QString levelText( const KoTextParag *paragraph );
+ TQString levelText( const KoTextParag *paragraph );
/** Return the current value of the counter as a text.
* This returns the full text, all levels included (if displayLevels>1),
* e.g. "1.2.1." if displayLevels==3.
*/
- QString text( const KoTextParag *paragraph );
+ TQString text( const KoTextParag *paragraph );
/**
* Work out the width of the text required for this counter.
@@ -68,9 +68,9 @@ public:
int bulletX();
/// KOffice-1.3 loading code
- void load( QDomElement & element );
+ void load( TQDomElement & element );
/// KOffice-1.3 saving code
- void save( QDomElement & element );
+ void save( TQDomElement & element );
/** Load from OASIS XML
* @param heading true if heading, false if normal list
* @param level 1-based
@@ -82,9 +82,9 @@ public:
*/
void loadOasis( KoOasisContext& context, int restartNumbering, bool orderedList, bool heading, int level, bool loadingStyle = false );
/// Part of loadOasis that is shared with KWVariableSettings::loadOasis for footnotes/endnotes
- void loadOasisListStyle( const QDomElement& listStyle,
- const QDomElement& listStyleProperties,
- const QDomElement& listStyleTextProperties,
+ void loadOasisListStyle( const TQDomElement& listStyle,
+ const TQDomElement& listStyleProperties,
+ const TQDomElement& listStyleTextProperties,
int restartNumbering,
bool orderedList, bool heading, int level, bool loadingStyle );
/// Save as OASIS XML
@@ -155,27 +155,27 @@ public:
/** Prefix and suffix strings.
*/
- QString prefix() const;
- void setPrefix( QString p );
- QString suffix() const;
- void setSuffix( QString s );
+ TQString prefix() const;
+ void setPrefix( TQString p );
+ TQString suffix() const;
+ void setSuffix( TQString s );
/** The character and font for STYLE_CUSTOMBULLET.
*/
- QChar customBulletCharacter() const;
- void setCustomBulletCharacter( QChar c );
- QString customBulletFont() const;
- void setCustomBulletFont( QString f );
+ TQChar customBulletCharacter() const;
+ void setCustomBulletCharacter( TQChar c );
+ TQString customBulletFont() const;
+ void setCustomBulletFont( TQString f );
/** The string STYLE_CUSTOM.
*/
- QString custom() const;
- void setCustom( QString c );
+ TQString custom() const;
+ void setCustom( TQString c );
- /** Counter alignment
+ /** Counter tqalignment
*/
- int alignment() const;
- void setAlignment( int a );
+ int tqalignment() const;
+ void tqsetAlignment( int a );
/**
* Return the format to use for the counter.
@@ -183,13 +183,13 @@ public:
*/
static KoTextFormat* counterFormat( const KoTextParag *paragraph );
- static QString makeRomanNumber( int n );
- static QString makeAlphaUpperNumber( int n );
- static QString makeAlphaLowerNumber( int n );
+ static TQString makeRomanNumber( int n );
+ static TQString makeAlphaUpperNumber( int n );
+ static TQString makeAlphaLowerNumber( int n );
- static int fromRomanNumber( const QString & );
- static int fromAlphaUpperNumber( const QString & );
- static int fromAlphaLowerNumber( const QString & );
+ static int fromRomanNumber( const TQString & );
+ static int fromAlphaUpperNumber( const TQString & );
+ static int fromAlphaLowerNumber( const TQString & );
#ifndef NDEBUG
void printRTDebug( KoTextParag* parag );
@@ -197,10 +197,10 @@ public:
private:
/** Return our parent paragraph, if there is such a thing. For a paragraph "1.1.",
* the parent is the paragraph numbered "1.".
*/
- KoTextParag *parent( const KoTextParag *paragraph );
+ KoTextParag *tqparent( const KoTextParag *paragraph );
Numbering m_numbering:3; // Numbering (maximum value: 8)
bool m_restartCounter:1;
@@ -210,12 +210,12 @@ private:
char m_depth;
short int m_startNumber;
- QChar m_customBulletChar;
+ TQChar m_customBulletChar;
- QString m_customBulletFont;
- QString m_custom;
- QString m_prefix;
- QString m_suffix;
+ TQString m_customBulletFont;
+ TQString m_custom;
+ TQString m_prefix;
+ TQString m_suffix;
int m_align;
class Private;
@@ -225,17 +225,17 @@ private:
*
* VALUE VALUE WHEN INVALID
* number of this counter -1
* text of this counter QString::null
* width of the label -1
- * parent (KoTextParag *)-1
+ * tqparent (KoTextParag *)-1
* the format that was used to calculate the width 0
*/
struct
{
int number;
- QString text;
+ TQString text;
int width;
- KoTextParag *parent;
+ KoTextParag *tqparent;
KoTextFormat * counterFormat;
} m_cache;
};
@@ -197,10 +197,10 @@ public:
private:
- /** Return our parent paragraph, if there is such a thing. For a paragraph "1.1.",
- * the parent is the paragraph numbered "1.".
+ /** Return our tqparent paragraph, if there is such a thing. For a paragraph "1.1.",
+ * the tqparent is the paragraph numbered "1.".
*/
@@ -225,17 +225,17 @@ private:
* VALUE VALUE WHEN INVALID
* number of this counter -1
- * text of this counter QString::null
+ * text of this counter TQString()
* width of the label -1